<?php

/**
 * Plugin Name: IPCamLive
 * Plugin URI: http://wordpress.org/plugins/ipcamlive/
 * Description: Easily add live video of your IP camera into your web page. Cloud based video broadcasting
 * solution for IP cameras. Easiest way to embed live video in your web page! Generate time-lapse video online!
 * Author: IPCamLive
 * Version: 1.0.8
 * Author URI: https://www.ipcamlive.com/
 * License: GPLv2 or later
 */

if ( ! defined( 'ABSPATH' ) ) exit;

//load short code file
function ipcamlive_load_cameras($atts) {
    
    $atts = shortcode_atts( array(
        'alias' => '',
        'features' => '',
        'aspectratio' => '',
        'boxwidth' => '',
    ), $atts, 'ipcamlive-loadcamera');

    wp_add_inline_script( 'jquery', '$ = jQuery;' );
    //wp_enqueue_script("ipcamliveplayer", "https://ipcamlive.com/player/ipcamliveplayer.debug.js", array( 'jquery' ));
    wp_enqueue_script("ipcamliveplayer", "https://ipcamlive.com/player/ipcamliveplayer.min.js", array( 'jquery' ));
    wp_enqueue_script('embed-video', plugins_url('/ipcamlive/assets/js/embed-video.js', __DIR__), array( 'jquery' ));
    
    return '<div id="'.uniqid().'" class="cameras" data-version="1.0.8" data-alias="'.$atts['alias'].'" data-ratio="'.$atts['aspectratio'].'" data-boxwidth="'.$atts['boxwidth'].'" data-features="'.$atts['features'].'"></div>';
}
add_shortcode('ipcamlive_load_camera', 'ipcamlive_load_cameras');

// load style
function ipcamlive_enqueue_scripts_and_styles()
{
    //wp_add_inline_script( 'jquery-core', '$ = jQuery;' );
    wp_enqueue_style("bs_css", plugins_url("/assets/css/bootstrap.min.css", __FILE__));
    wp_enqueue_script("ipcamliveplayer", "https://ipcamlive.com/player/ipcamliveplayer.min.js");
    
    wp_enqueue_style('admin-style', plugins_url('/assets/css/admin-page.css', __FILE__));
}
add_action('admin_enqueue_scripts', 'ipcamlive_enqueue_scripts_and_styles');

function ipcamlive_load_custom_gutenberg_block()
{
    wp_register_script('IPCamLive',plugins_url('/assets/js/my-block.js', __FILE__),array('wp-blocks', 'wp-i18n', 'wp-element', 'wp-editor', 'wp-components'));
    wp_enqueue_script('IPCamLive');
    
    // Localize the script with new data
    wp_localize_script( 'IPCamLive', 'js_data', array('icon' => plugins_url('/assets/ipcamlive-icons/Ipcamlive-admin-menu-icon.png', __FILE__)));
}
add_action('enqueue_block_editor_assets', 'ipcamlive_load_custom_gutenberg_block');

// create custom admin page
function ipcamlive_add_custom_admin_menu_button()
{
    $icon = plugins_url('/assets/ipcamlive-icons/Ipcamlive-admin-menu-icon.png', __FILE__);
    add_menu_page('IPCamLive', 'IPCamLive', 'manage_options', 'ipcamlive-admin-menu', 'ipcamlive_generate_custom_admin_page', $icon);
}
add_action('admin_menu', 'ipcamlive_add_custom_admin_menu_button');

// camera setup page
function ipcamlive_generate_custom_admin_page()
{
    class ipcamlive_features_buttons_class {
        
        public static $label=array('Skin of the player','Starts the video automatically','Mute the audio channel','Disable time-lapse player','Disable storage player','Disable auto full screen','Disable full screen button','Disable zoom button','Disable video fit button','Disable snapshot image button','Disable user pause button','Disable clip download button','Disable playback speed button','Disable camera navigation');
        public static $spam1=array('Orange','Off','Off','Off','Off','Off','Off','Off','Off','Off','Off','Off','Off','Off');
        public static $spam2=array('White','On','On','On','On','On','On','On','On','On','On','On','On','On');
        public static $btn_tags = array("skin","autoplay","mute","disabletimelapseplayer","disablestorageplayer","disableautofullscreen","disablefullscreen","disablezoombutton","disablevideofit","disableframecapture","disableuserpause","disabledownloadbutton","disableplaybackspeedbutton","disablenavigation");

        function show_buttons()
        {
            $elements = count(self::$label);

            for($i=0; $i<$elements; $i++){

                if($i <= 7)
                {
                ?>
                    <div class="col-12 col-sm-6 mt-4 <?php echo esc_html('switch'.$i) ?> switch-btns order-2">
                        <p class="label mb-0"><?php echo esc_html(self::$label[$i]) ?></p>
                        <label class="switch">
                            <input id="<?php echo esc_html('switch'.$i) ?>" type="checkbox" class='checkbox' data-feature="<?php echo esc_html(self::$btn_tags[$i]) ?>">
                            <span class="slider round">
                                <span id="<?php echo esc_html('no-checked'.$i) ?>" class="span no-checked pe-2"><?php echo esc_html(self::$spam1[$i]) ?></span>
                                <span id="<?php echo esc_html('checked'.$i) ?>" class="span checked ps-2"><?php echo esc_html(self::$spam2[$i]) ?></span>
                            </span>
                        </label>
                    </div>
                <?php
                } else {
                ?>
                    <div class="col-12 col-sm-6 mt-4 <?php echo esc_html('switch'.$i) ?> switch-btns order-2">
                        <p class="label mb-0"><?php echo esc_html(self::$label[$i]) ?></p>
                        <label class="switch">
                            <input id="<?php echo esc_html('switch'.$i) ?>" type="checkbox" class='checkbox' data-feature="<?php echo esc_html(self::$btn_tags[$i]) ?>">
                            <span class="slider round">
                                <span id="<?php echo esc_html('no-checked'.$i) ?>" class="span no-checked pe-2"><?php echo esc_html(self::$spam1[$i]) ?></span>
                                <span id="<?php echo esc_html('checked'.$i) ?>" class="span checked ps-2"><?php echo esc_html(self::$spam2[$i]) ?></span>
                            </span>
                        </label>
                    </div>
                <?php
                }
            }

            //blocked buttons block
            ?>

            <div id="post-method-block"></div>

            <?php
        }
    }

    // create buttons object
    $buttons_obj = new Ipcamlive_features_buttons_class();
    
?>
    <div class="container-fluid ipcamlive">
        <div class="ipcl_alert_block w-100"></div>

        <div class="row w-100 ms-0 mt-3">
            <div class="col-12 col-md-6">
                <h1 id="live-video-setup" class="text-center mb-4">LIVE VIDEO SETUP</h1>

                <!-- applied camera setups -->
                <h5 class="mt-3 mb-3">Configured cameras</h5>

                <div class="table-responsive" style="max-height: 400px">
                    <table class="table table-light">
                        <tbody id="applied_cameras">
                            <tr>
                                <td><div id="mediadiv1"> </div></td>
                            </tr>
                        </tbody>
                    </table>
                </div>

                <div class="apply-debug-mode-div d-flex align-items-center mt-3 mb-0 alert alert-info d-none">
                    <h6 class="pe-2 mb-0">Do you apply debug mode?</h6>
                    <input type="checkbox" class="apply-debug-mode-checkbox my-auto" value="0" />
                </div>

                <!-- ************************ NEW CAMERA BLOCK ************************************** -->
                <div class="row w-100 ms-0 justify-content-center mt-5">
                    <button type="button" id="new-camera" class="btn" style="width: fit-content;"><svg class="pe-2" xmlns="http://www.w3.org/2000/svg" height="1em" viewBox="0 0 512 512"><!--! Font Awesome Free 6.4.0 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license (Commercial License) Copyright 2023 Fonticons, Inc. --><style>svg{fill:#ffffff}</style><path d="M416 208c0 45.9-14.9 88.3-40 122.7L502.6 457.4c12.5 12.5 12.5 32.8 0 45.3s-32.8 12.5-45.3 0L330.7 376c-34.4 25.2-76.8 40-122.7 40C93.1 416 0 322.9 0 208S93.1 0 208 0S416 93.1 416 208zM208 352a144 144 0 1 0 0-288 144 144 0 1 0 0 288z"/></svg>Add new camera</button>
                </div>

                <!-- Camera id -->
                <div id="camera_setup_block" class="w-100 mt-5 d-none">
                    <div class="row w-100 ms-0 justify-content-center">
                        <div class="mb-3">
                            <div class="d-flex flex-nowrap">
                                <input type="text"
                                class="form-control" name="cameraAlias" id="cameraAlias" aria-describedby="helpId" placeholder="IPCamLive camera alias">
                                <button type="button" id="save_btn" class="btn ms-3">Save</button>
                            </div>
                            <small id="helpId" class="form-text text-muted ms-1">Write here your IPCamLive camera alias</small>
                        </div>
                    </div>

                    <!-- Video JS -->
                    <div id="video-block" class="row w-100 ms-0 justify-content-center mb-5">
                        <div id="mediadiv" class="ps-0 pe-0" style="background-color: #A0A0A0;">
                        </div>
                        <!-- call show_buttons function -->
                        <?php $buttons_obj->show_buttons(); ?>

                        <div id="apply-buttons" class="col-12 d-flex justify-content-center mt-5 order-3">
                            
                        </div>
                    </div>
                </div>

            </div>

            <div class="col-12 col-md-6 pt-5">
                <?php include( plugin_dir_path( __FILE__ ) . '/includes/how-to-setup.php') ?>
            </div>

        </div>

        <!-- ******************** modal to delete ******************************** -->
        <!-- Modal -->
        <div class="modal" id="modalId" tabindex="-1" role="dialog" aria-labelledby="modalTitleId" aria-hidden="true">
            <div class="modal-dialog modal-dialog-centered" role="document">
                <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="modalTitleId">Setuped camera delete</h5>
                        </div>
                    <div class="modal-body">
                        <div class="container-fluid">
                            Are you sure to delete the selected camera?
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" id="item_delete_close" class="btn">No</button>
                        <button type="button" id="item_delete_yes" class="btn" data-id="">Yes</button>
                    </div>
                </div>
            </div>
        </div>
        <script>
            jQuery("#item_delete_close").click(() => {
                jQuery("#modalId").hide("slow");
            })
        </script>
        
    </div>
<?php

    include( plugin_dir_path( __FILE__ ) . '/includes/admin-page.php');
}
